@@ -1,24 +1,46 @@
 #' @export
 #' @title concatenate formatted text
 #' @description Create a paragraph representation by concatenating
-#' formatted text or images. Modify default text and paragraph
-#' formatting properties with update.
+#' formatted text or images.
+#'
+#' \code{fpar} supports \code{ftext}, \code{external_img} and simple strings.
+#' All its arguments will be concatenated to create a paragraph where chunks
+#' of text and images are associated with formatting properties.
+#'
+#' Default text and paragraph formatting properties can also
+#' be modified with update.
 #' @details
 #' \code{fortify_fpar}, \code{as.data.frame} are used internally and
 #' are not supposed to be used by end user.
 #'
 #' @param fp_p paragraph formatting properties
-#' @param fp_t default text formatting properties
+#' @param fp_t default text formatting properties. This is used as
+#' text formatting properties when simple text is provided as argument.
+#'
 #' @param x,object fpar object
 #' @examples
 #' fpar(ftext("hello", shortcuts$fp_bold()))
-fpar <- function( ... ) {
+#'
+#' # mix text and image -----
+#' img.file <- file.path( R.home("doc"), "html", "logo.jpg" )
+#'
+#' bold_face <- shortcuts$fp_bold(font.size = 12)
+#' bold_redface <- update(bold_face, color = "red")
+#' fpar_1 <- fpar(
+#'   "Hello World, ",
+#'   ftext("how ", prop = bold_redface ),
+#'   external_img(src = img.file, height = 1.06/2, width = 1.39/2),
+#'   ftext(" you?", prop = bold_face ) )
+#' fpar_1
+#'
+#' img_in_par <- fpar(
+#'   external_img(src = img.file, height = 1.06/2, width = 1.39/2),
+#'   fp_p = fp_par(text.align = "center") )
+fpar <- function( ..., fp_p = fp_par(), fp_t = fp_text() ) {
   out <- list()
   out$chunks <- list(...)
-
-  out$fp_p <- fp_par()
-  out$fp_t <- fp_text()
-
+  out$fp_p <- fp_p
+  out$fp_t <- fp_t
   class(out) <- c("fpar")
   out
 }
@@ -26,7 +48,8 @@ fpar <- function( ... ) {
 #' @export
 #' @rdname fpar
 #' @importFrom stats update
-update.fpar <- function (object, fp_p=NULL, fp_t=NULL, ...){
+update.fpar <- function (object, fp_p = NULL, fp_t = NULL, ...){
+
   if(!is.null(fp_p)){
     object$fp_p <- fp_p
   }
@@ -38,8 +61,6 @@ update.fpar <- function (object, fp_p=NULL, fp_t=NULL, ...){
 }
 
 
-#' @export
-#' @rdname fpar
 fortify_fpar <- function(x){
   lapply(x$chunks, function(chk) {
     if( !inherits(chk, "cot") ){
@@ -86,7 +107,6 @@ format.fpar <- function( x, type = "pml", ...){
 }
 
 #' @export
-#' @rdname fpar
 print.fpar = function (x, ...){
   cat( format(x, type = "console"), "\n", sep = "" )
 }
