@@ -226,7 +226,7 @@ read_xlsx <- function( path = NULL ){
   obj$content_type <- content_type$new( package_dir )
   obj$worksheets <- worksheets$new(package_dir)
   obj$sheets <- dir_sheet$new( obj )
-  obj$core_properties <- core_properties$new(obj$package_dir)
+  obj$core_properties <- read_core_properties(obj$package_dir)
 
   obj
 }
@@ -318,9 +318,9 @@ print.rxlsx <- function(x, target = NULL, ...){
   x$worksheets$save()
   x$content_type$save()
 
-  x$core_properties$set_last_modified(format( Sys.time(), "%Y-%m-%dT%H:%M:%SZ"))
-  x$core_properties$set_modified_by(Sys.getenv("USER"))
-  x$core_properties$save()
+  x$core_properties['modified','value'] <- format( Sys.time(), "%Y-%m-%dT%H:%M:%SZ")
+  x$core_properties['lastModifiedBy','value'] <- Sys.getenv("USER")
+  write_core_properties(x$core_properties, x$package_dir)
 
   pack_folder(folder = x$package_dir, target = target )
 }
