@@ -8,7 +8,6 @@ public:
   tcpr(std::string, std::string,
        int, int, int, int,
        int, int, int, int,
-       bool, std::string, std::string,
        IntegerVector, IntegerVector,
        IntegerVector, IntegerVector,
        CharacterVector, DoubleVector
@@ -22,8 +21,5 @@ private:
   std::string text_direction;
   int mb, mt, ml, mr;
   int shading_r, shading_g, shading_b, shading_a;
-  bool do_bgimg;
-  std::string bgimg_rid;
-  std::string bgimg_path;
   border b,t,l,r;
 };
